# Tool usage

## Category 1: Tests for regions versus regions

### Projection Test

Commands:
```shell
rgt-viz projection -r <experiment_matrix_ref> -q <experiment_matrix_que> <output_directory> [options]
```

Required Inputs:
| Option Name      | Type | Default |Description|
| ----------- | ----------- | ----------- |----------- |
|experiment_matrix_ref|File|None|The experiment matrix should contain all the reference regions for projection test. Check more details on Experiment Matrix Format.|